package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1SequenceParser;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.ASN1SetParser;
import cn.com.infosec.asn1.ASN1TaggedObjectParser;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import java.io.IOException;

public class SignedDataParser {
   private ASN1SequenceParser _seq;
   private DERInteger _version;
   private Object _nextObject;
   private boolean _certsCalled;
   private boolean _crlsCalled;

   public static SignedDataParser getInstance(Object o) {
      if (o instanceof ASN1Sequence) {
         return new SignedDataParser(((ASN1Sequence)o).parser());
      } else if (o instanceof ASN1SequenceParser) {
         return new SignedDataParser((ASN1SequenceParser)o);
      } else {
         throw new IOException("unknown object encountered: " + o.getClass().getName());
      }
   }

   private SignedDataParser(ASN1SequenceParser seq) {
      this._seq = seq;
      this._version = (DERInteger)seq.readObject();
   }

   public DERInteger getVersion() {
      return this._version;
   }

   public ASN1SetParser getDigestAlgorithms() {
      DEREncodable var1;
      return (var1 = this._seq.readObject()) instanceof ASN1Set ? ((ASN1Set)var1).parser() : (ASN1SetParser)var1;
   }

   public ContentInfoParser getEncapContentInfo() {
      return new ContentInfoParser((ASN1SequenceParser)this._seq.readObject());
   }

   public ASN1SetParser getCertificates() {
      this._certsCalled = true;
      DEREncodable var1;
      this._nextObject = var1 = this._seq.readObject();
      if (var1 instanceof ASN1TaggedObjectParser && ((ASN1TaggedObjectParser)var1).getTagNo() == 0) {
         ASN1SetParser var10000 = (ASN1SetParser)((ASN1TaggedObjectParser)this._nextObject).getObjectParser(17, false);
         this._nextObject = null;
         return var10000;
      } else {
         return null;
      }
   }

   public ASN1SetParser getCrls() {
      if (this._certsCalled) {
         this._crlsCalled = true;
         if (this._nextObject == null) {
            this._nextObject = this._seq.readObject();
         }

         Object var1;
         if ((var1 = this._nextObject) instanceof ASN1TaggedObjectParser && ((ASN1TaggedObjectParser)var1).getTagNo() == 1) {
            ASN1SetParser var10000 = (ASN1SetParser)((ASN1TaggedObjectParser)this._nextObject).getObjectParser(17, false);
            this._nextObject = null;
            return var10000;
         } else {
            return null;
         }
      } else {
         throw new IOException("getCerts() has not been called.");
      }
   }

   public ASN1SetParser getSignerInfos() {
      if (this._certsCalled && this._crlsCalled) {
         if (this._nextObject == null) {
            this._nextObject = this._seq.readObject();
         }

         return (ASN1SetParser)this._nextObject;
      } else {
         throw new IOException("getCerts() and/or getCrls() has not been called.");
      }
   }
}
